#! /usr/bin/perl

use strict;
use warnings;
use Test::More qw(no_plan);

# @TODO write tests for
# bad-hash.dane.verisignlabs.com -> The TLSA record for this server has an incorrect hash value, although it is correctly signed with DNSSEC
# bad-params.dane.verisignlabs.com -> The TLSA record for this server has a correct hash value, incorrect TLSA parameters, and is correctly signed with DNSSEC. NOTE: The current Firefox plugin accepts these TLSA records as valid.
# bad-sig.dane.verisignlabs.com -> The TLSA record for this server is correct, but the DNSSEC chain-of-trust is broken and/or has a bad signature. NOTE: If you have validation enabled you won't be able to look up the hostname anyway.
# source: http://dane.verisignlabs.com/

BEGIN { use_ok('Nagios::Check::DNS::check_tlsa_record') }

require_ok('Nagios::Check::DNS::check_tlsa_record');

#HTTP Domains
my $domain  = 'ssl.schlittermann.de';
my $domain2 = 'torproject.org';
my $domain3 = 'freebsd.org';
my $domain4 = 'bad-hash.dane.verisignlabs.com'
  ; # The TLSA record for this server has an incorrect hash value, although it is correctly signed with DNSSEC

#smtpdomains
my $sdomain = 'hh.schlittermann.de';

sub test_main() {
    my $test_main_default_port =
      Nagios::Check::DNS::check_tlsa_record::main(($domain));
    like(
        $test_main_default_port,
        qr(OK: .* is valid),
        'main() ok with domain and default port 443'
    );

    my $test_main_domain_and_port =
      Nagios::Check::DNS::check_tlsa_record::main(($sdomain, 25));
    like(
        $test_main_domain_and_port,
        qr(OK: .* is valid),
        'main() ok with domain and port'
    );

    my $test_main_domain_port_protocol =
      Nagios::Check::DNS::check_tlsa_record::main(($domain3, 443, 'tcp'));
    like(
        $test_main_domain_port_protocol,
        qr(OK: .* is valid),
        'main() ok with domain, port and protocol'
    );

    my $test_main_no_tlsa =
      Nagios::Check::DNS::check_tlsa_record::main(('google.com'));
    like(
        $test_main_no_tlsa,
        qr(UNKNOWN: .*),
'main() unknown when no DANE is available'
    );

    my $test_main_default_port2 =
      Nagios::Check::DNS::check_tlsa_record::main(($domain4));
    like(
        $test_main_default_port2,
        qr(CRITICAL: .* valid),
        'main() critical when DANE not valid.'
    );

}

#sub test_dig() {

#my $test_dig_tlsa = Nagios::Check::DNS::check_tlsa_record::dig_tlsa($domain, 25, 'tcp');
#my $test_dig_tlsa = Nagios::Check::DNS::check_tlsa_record::get_tlsa_from_dns($domain, 443);
#like($test_dig_tlsa, qr(^[0-3]{1}\s[01]{1}\s[0-2]{1}\s[A-F0-9]{56}\s[A-F0-9]{8}), 'dig_tlsa() returnd format looks like an valid answer to dig tlsa');

#}

test_main();

#test_dig();

#@TODO write tests
#my $return2 = Nagios::Check::DNS::check_tlsa_record::dig_tlsa(qw(hh.schlittermann.de 25 udp));
#say $return2;
#
#my $return3 = Nagios::Check::DNS::check_tlsa_record::dig_tlsa(qw(hh.schlittermann.de 25));
#say $return3;
#
#my $return4 = Nagios::Check::DNS::check_tlsa_record::dig_tlsa(qw(hh.schlittermann.de));
#say $return4;

# vim: ft=perl ts=2 sw=2
